@@ -16,7 +16,7 @@ pub struct BinaryHeap<T, C = MaxComparator>
 where
     C: Compare<T>,
 {
-    data: Vec<T>,
+    pub data: Vec<T>,
     cmp: C,
 }
 
